#
# spec file for package python-boto3
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-boto3
Version:        1.17.9
Release:        19.1
Summary:        Amazon Web Services Library
License:        Apache-2.0
URL:            https://github.com/boto/boto3
Source:         https://github.com/boto/boto3/archive/%{version}.tar.gz
# Related test dependencies
BuildRequires:  %{python_module botocore < 1.21.0}
BuildRequires:  %{python_module botocore >= 1.20.9}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module s3transfer < 0.4.0}
BuildRequires:  %{python_module s3transfer >= 0.3.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-botocore < 1.21.0
Requires:       python-botocore >= 1.20.9
Requires:       python-jmespath < 1.0.0
Requires:       python-jmespath >= 0.7.1
Requires:       python-s3transfer < 0.4.0
Requires:       python-s3transfer >= 0.3.0
Requires:       python-six
BuildArch:      noarch
%if 0%{?suse_version} <= 1315
# We need the ssl module, which is provided by python and not python-base
BuildRequires:  python
%endif
%if %{with python2}
BuildRequires:  python-futures
%endif
%ifpython2
Requires:       python-futures
%endif
%python_subpackages

%description
Boto3 is the Amazon Web Services (AWS) Software Development Kit (SDK) for
Python, which allows Python developers to write software that makes use of
services like Amazon S3 and Amazon EC2.

For documentation consult the online documentation at
http://boto3.readthedocs.org/en/latest/

# Note to maintainers also familia with python-boto:
# The documentation generation requires access to AWS, thus it is not
# possible to generate the documentation in OBS

%prep
%setup -q -n boto3-%{version}
sed -i 's/from botocore.vendored //' boto3/compat.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand nosetests-%{$python_bin_suffix} -v tests/unit

%files %{python_files}
%license LICENSE
%doc CONTRIBUTING.rst README.rst
%{python_sitelib}/*

%changelog
* Tue Jul  6 2021 adrian.glaubitz@suse.com
- Enable python2 builds for SLE-15
* Thu Feb 18 2021 adrian.glaubitz@suse.com
- Version update to 1.17.9 (bsc#1182421, bsc#1182422, jsc#ECO-3352, jsc#PM-2485)
  * api-change:``devops-guru``: [``botocore``] Update devops-guru client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
- from version 1.17.8
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``kinesis-video-archived-media``: [``botocore``] Update kinesis-video-archived-media
    client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``redshift-data``: [``botocore``] Update redshift-data client to latest version
  * api-change:``workmailmessageflow``: [``botocore``] Update workmailmessageflow client to latest version
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
- from version 1.17.7
  * api-change:``personalize-events``: [``botocore``] Update personalize-events client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``detective``: [``botocore``] Update detective client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``wafv2``: [``botocore``] Update wafv2 client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.17.6
  * api-change:``databrew``: [``botocore``] Update databrew client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.17.5
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``qldb-session``: [``botocore``] Update qldb-session client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
- from version 1.17.4
  * api-change:``dataexchange``: [``botocore``] Update dataexchange client to latest version
  * api-change:``cloudtrail``: [``botocore``] Update cloudtrail client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``ivs``: [``botocore``] Update ivs client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
- from version 1.17.3
  * api-change:``macie``: [``botocore``] Update macie client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.17.2
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``appflow``: [``botocore``] Update appflow client to latest version
  * api-change:``emr-containers``: [``botocore``] Update emr-containers client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.17.1
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``databrew``: [``botocore``] Update databrew client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
  * api-change:``auditmanager``: [``botocore``] Update auditmanager client to latest version
  * api-change:``compute-optimizer``: [``botocore``] Update compute-optimizer client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
- from version 1.17.0
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * feature:Python: Dropped support for Python 3.4 and 3.5
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling
  client to latest version
  * api-change:``lookoutvision``: [``botocore``] Update lookoutvision client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * feature:Python: [``botocore``] Dropped support for Python 3.4 and 3.5
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
  * api-change:``rds-data``: [``botocore``] Update rds-data client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``location``: [``botocore``] Update location client to latest version
  * enhancement:s3: [``botocore``] Amazon S3 now supports AWS PrivateLink, providing direct access
    to S3 via a private endpoint within your virtual private network.
  * api-change:``iotwireless``: [``botocore``] Update iotwireless client to latest version
- from version 1.16.63
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.16.62
  * api-change:``wellarchitected``: [``botocore``] Update wellarchitected client to latest version
  * api-change:``managedblockchain``: [``botocore``] Update managedblockchain client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``databrew``: [``botocore``] Update databrew client to latest version
  * bugfix:Validator: [``botocore``] Fix showing incorrect max-value in error message for
    range and length value validation
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
- from version 1.16.61
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``customer-profiles``: [``botocore``] Update customer-profiles client to latest version
  * api-change:``sesv2``: [``botocore``] Update sesv2 client to latest version
  * api-change:``accessanalyzer``: [``botocore``] Update accessanalyzer client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
- from version 1.16.60
  * api-change:``backup``: [``botocore``] Update backup client to latest version
- from version 1.16.59
  * api-change:``greengrassv2``: [``botocore``] Update greengrassv2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``lexv2-runtime``: [``botocore``] Update lexv2-runtime client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``lexv2-models``: [``botocore``] Update lexv2-models client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.16.58
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi
    client to latest version
- from version 1.16.57
  * api-change:``acm-pca``: [``botocore``] Update acm-pca client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.16.56
  * api-change:``sns``: [``botocore``] Update sns client to latest version
- from version 1.16.55
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``cognito-identity``: [``botocore``] Update cognito-identity client to latest version
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.16.54
  * api-change:``frauddetector``: [``botocore``] Update frauddetector client to latest version
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
- from version 1.16.53
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``auditmanager``: [``botocore``] Update auditmanager client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
- Update BuildRequires and Requires from setup.py
* Tue Jan 12 2021 adrian.glaubitz@suse.com
- Version update to 1.16.52
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
- from version 1.16.51
  * api-change:``devops-guru``: [``botocore``] Update devops-guru client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.16.50
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``autoscaling-plans``: [``botocore``] Update autoscaling-plans client to latest version
- from version 1.16.49
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling
    client to latest version
- from version 1.16.48
  * api-change:``healthlake``: [``botocore``] Update healthlake client to latest version
  * api-change:``cloudsearch``: [``botocore``] Update cloudsearch client to latest version
- from version 1.16.47
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- from version 1.16.46
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
- from version 1.16.45
  * api-change:``acm-pca``: [``botocore``] Update acm-pca client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
- from version 1.16.44
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
- from version 1.16.43
  * api-change:``compute-optimizer``: [``botocore``] Update compute-optimizer client to latest version
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
- from version 1.16.42
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``iotwireless``: [``botocore``] Update iotwireless client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
- from version 1.16.41
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``managedblockchain``: [``botocore``] Update managedblockchain client to latest version
  * api-change:``service-quotas``: [``botocore``] Update service-quotas client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``connectparticipant``: [``botocore``] Update connectparticipant client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``qldb-session``: [``botocore``] Update qldb-session client to latest version
  * api-change:``outposts``: [``botocore``] Update outposts client to latest version
  * api-change:``servicecatalog-appregistry``: [``botocore``] Update servicecatalog-appregistry
    client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
- from version 1.16.40
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * bugfix:SSO: [``botocore``] Fixed timestamp format for SSO credential expirations
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime
    client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.16.39
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
  * api-change:``route53resolver``: [``botocore``] Update route53resolver client to latest version
  * api-change:``sqs``: [``botocore``] Update sqs client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
- from version 1.16.38
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``amp``: [``botocore``] Update amp client to latest version
  * api-change:``location``: [``botocore``] Update location client to latest version
  * api-change:``wellarchitected``: [``botocore``] Update wellarchitected client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
- from version 1.16.37
  * api-change:``iotwireless``: [``botocore``] Update iotwireless client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``greengrassv2``: [``botocore``] Update greengrassv2 client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``iotdeviceadvisor``: [``botocore``] Update iotdeviceadvisor client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
  * api-change:``amp``: [``botocore``] Update amp client to latest version
  * api-change:``iotfleethub``: [``botocore``] Update iotfleethub client to latest version
- from version 1.16.36
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator
    client to latest version
  * api-change:``devops-guru``: [``botocore``] Update devops-guru client
    to latest version
- from version 1.16.35
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``pi``: [``botocore``] Update pi client to latest version
  * api-change:``cloudtrail``: [``botocore``] Update cloudtrail client to latest version
- from version 1.16.34
  * api-change:``networkmanager``: [``botocore``] Update networkmanager
    client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.16.33
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator
    client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
- from version 1.16.32
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``auditmanager``: [``botocore``] Update auditmanager client to latest version
  * api-change:``sagemaker-runtime``: [``botocore``] Update sagemaker-runtime client to latest version
  * api-change:``sagemaker-edge``: [``botocore``] Update sagemaker-edge client to latest version
  * api-change:``forecast``: [``botocore``] Update forecast client to latest version
  * api-change:``healthlake``: [``botocore``] Update healthlake client to latest version
  * api-change:``emr-containers``: [``botocore``] Update emr-containers client to latest version
- from version 1.16.31
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``servicecatalog-appregistry``: [``botocore``] Update servicecatalog-appregistry
    client to latest version
- from version 1.16.30
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``license-manager``: [``botocore``] Update license-manager client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.16.29
  * api-change:``license-manager``: [``botocore``] Update license-manager client to latest version
  * api-change:``compute-optimizer``: [``botocore``] Update compute-optimizer client to latest version
  * api-change:``amplifybackend``: [``botocore``] Update amplifybackend client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
- from version 1.16.28
  * api-change:``customer-profiles``: [``botocore``] Update customer-profiles
    client to latest version
- from version 1.16.27
  * api-change:``sagemaker-featurestore-runtime``: [``botocore``] Update
    sagemaker-featurestore-runtime client to latest version
  * api-change:``ecr-public``: [``botocore``] Update ecr-public client to latest version
  * api-change:``honeycode``: [``botocore``] Update honeycode client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``amplifybackend``: [``botocore``] Update amplifybackend client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``lookoutvision``: [``botocore``] Update lookoutvision client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``connect-contact-lens``: [``botocore``] Update connect-contact-lens client to latest version
  * api-change:``profile``: [``botocore``] Update profile client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``appintegrations``: [``botocore``] Update appintegrations client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
  * api-change:``devops-guru``: [``botocore``] Update devops-guru client to latest version
- from version 1.16.26
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- Update BuildRequires and Requires from setup.py
* Mon Nov 30 2020 adrian.glaubitz@suse.com
- Version update to 1.16.25
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``appflow``: [``botocore``] Update appflow client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``timestream-write``: [``botocore``] Update timestream-write client to latest version
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``cloudtrail``: [``botocore``] Update cloudtrail client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``mwaa``: [``botocore``] Update mwaa client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
- from version 1.16.24
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``translate``: [``botocore``] Update translate client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``application-insights``: [``botocore``] Update application-insights client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``signer``: [``botocore``] Update signer client to latest version
  * api-change:``codestar-connections``: [``botocore``] Update codestar-connections client to latest version
  * api-change:``codeartifact``: [``botocore``] Update codeartifact client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``forecast``: [``botocore``] Update forecast client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``timestream-query``: [``botocore``] Update timestream-query client to latest version
  * api-change:``sso-admin``: [``botocore``] Update sso-admin client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``outposts``: [``botocore``] Update outposts client to latest version
  * api-change:``license-manager``: [``botocore``] Update license-manager client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
- from version 1.16.23
  * api-change:``servicecatalog-appregistry``: [``botocore``] Update servicecatalog-appregistry client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``cloudhsmv2``: [``botocore``] Update cloudhsmv2 client to latest version
  * api-change:``codeguru-reviewer``: [``botocore``] Update codeguru-reviewer client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``cognito-identity``: [``botocore``] Update cognito-identity client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
- from version 1.16.22
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``lex-runtime``: [``botocore``] Update lex-runtime client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
  * api-change:``kinesisanalyticsv2``: [``botocore``] Update kinesisanalyticsv2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
- from version 1.16.21
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * bugfix:Retry: [``botocore``] Fix bug where retries were attempted on any response with an "Error" key.
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
  * api-change:``backup``: [``botocore``] Update backup client to latest version
  * api-change:``outposts``: [``botocore``] Update outposts client to latest version
- from version 1.16.20
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``fms``: [``botocore``] Update fms client to latest version
  * api-change:``network-firewall``: [``botocore``] Update network-firewall client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
- from version 1.16.19
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``iotsecuretunneling``: [``botocore``] Update iotsecuretunneling client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``synthetics``: [``botocore``] Update synthetics client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
- from version 1.16.18
  * api-change:``textract``: [``botocore``] Update textract client to latest version
  * api-change:``shield``: [``botocore``] Update shield client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
- from version 1.16.17
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime client to latest version
  * api-change:``servicecatalog-appregistry``: [``botocore``] Update servicecatalog-appregistry client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``polly``: [``botocore``] Update polly client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
- from version 1.16.16
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``databrew``: [``botocore``] Update databrew client to latest version
  * api-change:``forecast``: [``botocore``] Update forecast client to latest version
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
- from version 1.16.15
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.16.14
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
- from version 1.16.13
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
- from version 1.16.12
  * api-change:``frauddetector``: [``botocore``] Update frauddetector client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
- from version 1.16.11
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
  * api-change:``mq``: [``botocore``] Update mq client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``meteringmarketplace``: [``botocore``] Update meteringmarketplace client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- from version 1.16.10
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.16.9
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``braket``: [``botocore``] Update braket client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
- from version 1.16.8
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``codeartifact``: [``botocore``] Update codeartifact client to latest version
  * api-change:``marketplacecommerceanalytics``: [``botocore``] Update marketplacecommerceanalytics client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``sesv2``: [``botocore``] Update sesv2 client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
- from version 1.16.7
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
- from version 1.16.6
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.16.5
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``neptune``: [``botocore``] Update neptune client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
- from version 1.16.4
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
- from version 1.16.3
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``accessanalyzer``: [``botocore``] Update accessanalyzer client to latest version
  * api-change:``appflow``: [``botocore``] Update appflow client to latest version
- from version 1.16.2
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.16.1
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
- from version 1.16.0
  * api-change:``backup``: [``botocore``] Update backup client to latest version
  * api-change:``docdb``: [``botocore``] Update docdb client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * feature:imds: [``botocore``] Updated InstanceMetadataFetcher to use custom ipv6 uri as endpoint if envvar or config set
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.15.18
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.15.17
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``groundstation``: [``botocore``] Update groundstation client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``budgets``: [``botocore``] Update budgets client to latest version
  * api-change:``accessanalyzer``: [``botocore``] Update accessanalyzer client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
- from version 1.15.16
  * api-change:``snowball``: [``botocore``] Update snowball client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- Update BuildRequires and Requires from setup.py
* Thu Nov 26 2020 rjschwei@suse.com
- Only build Python3 flavors for distributions 15 and greater
* Fri Oct  9 2020 adrian.glaubitz@suse.com
- Version update to 1.15.15
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- from version 1.15.14
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``compute-optimizer``: [``botocore``] Update compute-optimizer client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
- from version 1.15.13
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``kinesisanalyticsv2``: [``botocore``] Update kinesisanalyticsv2 client to latest version
  * api-change:``marketplace-catalog``: [``botocore``] Update marketplace-catalog client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.15.12
  * api-change:``dynamodbstreams``: [``botocore``] Update dynamodbstreams client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.15.11
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``personalize-events``: [``botocore``] Update personalize-events client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``servicediscovery``: [``botocore``] Update servicediscovery client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.15.10
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``wafv2``: [``botocore``] Update wafv2 client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
- from version 1.15.9
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``s3outposts``: [``botocore``] Update s3outposts client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
- from version 1.15.8
  * api-change:``timestream-write``: [``botocore``] Update timestream-write client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``schemas``: [``botocore``] Update schemas client to latest version
  * api-change:``timestream-query``: [``botocore``] Update timestream-query client to latest version
- from version 1.15.7
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.15.6
  * api-change:``frauddetector``: [``botocore``] Update frauddetector client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``docdb``: [``botocore``] Update docdb client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``sts``: [``botocore``] Update sts client to latest version
- from version 1.15.5
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``textract``: [``botocore``] Update textract client to latest version
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``savingsplans``: [``botocore``] Update savingsplans client to latest version
  * api-change:``synthetics``: [``botocore``] Update synthetics client to latest version
- from version 1.15.4
  * api-change:``translate``: [``botocore``] Update translate client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``backup``: [``botocore``] Update backup client to latest version
- from version 1.15.3
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``dynamodbstreams``: [``botocore``] Update dynamodbstreams client to latest version
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
- from version 1.15.2
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.15.1
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``sso-admin``: [``botocore``] Update sso-admin client to latest version
  * api-change:``codestar-connections``: [``botocore``] Update codestar-connections client to latest version
- from version 1.15.0
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
  * feature:dependency: [``botocore``] botocore has removed docutils as a required dependency
- from version 1.14.63
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.14.62
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``budgets``: [``botocore``] Update budgets client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.14.61
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``managedblockchain``: [``botocore``] Update managedblockchain client to latest version
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``docdb``: [``botocore``] Update docdb client to latest version
- from version 1.14.60
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
- from version 1.14.59
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``ebs``: [``botocore``] Update ebs client to latest version
  * api-change:``sso-admin``: [``botocore``] Update sso-admin client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.14.58
  * api-change:``kinesisanalyticsv2``: [``botocore``] Update kinesisanalyticsv2 client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``redshift-data``: [``botocore``] Update redshift-data client to latest version
- from version 1.14.57
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
- Update BuildRequires and Requires from setup.py
* Mon Sep  7 2020 adrian.glaubitz@suse.com
- Version update to 1.14.56
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.14.55
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
- from version 1.14.54
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
- from version 1.14.53
  * api-change:``codeguru-reviewer``: [``botocore``] Update codeguru-reviewer client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
- from version 1.14.52
  * api-change:``sqs``: [``botocore``] Update sqs client to latest version
  * api-change:``backup``: [``botocore``] Update backup client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.14.51
  * api-change:``cur``: [``botocore``] Update cur client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
- from version 1.14.50
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.14.49
  * api-change:``appflow``: [``botocore``] Update appflow client to latest version
  * api-change:``route53resolver``: [``botocore``] Update route53resolver client to latest version
- from version 1.14.48
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``logs``: [``botocore``] Update logs client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
- from version 1.14.47
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
- from version 1.14.46
  * api-change:``lakeformation``: [``botocore``] Update lakeformation client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``ivs``: [``botocore``] Update ivs client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- from version 1.14.45
  * api-change:``identitystore``: [``botocore``] Update identitystore client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``sesv2``: [``botocore``] Update sesv2 client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
- from version 1.14.44
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``kinesis``: [``botocore``] Update kinesis client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``acm``: [``botocore``] Update acm client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``elb``: [``botocore``] Update elb client to latest version
  * api-change:``acm-pca``: [``botocore``] Update acm-pca client to latest version
- from version 1.14.43
  * api-change:``braket``: [``botocore``] Update braket client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``license-manager``: [``botocore``] Update license-manager client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
- from version 1.14.42
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``braket``: [``botocore``] Update braket client to latest version
- from version 1.14.41
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``cloud9``: [``botocore``] Update cloud9 client to latest version
- Update BuildRequires and Requires from setup.py
* Wed Aug 12 2020 adrian.glaubitz@suse.com
- Version update to 1.14.40 (bsc#1175147, bsc#1175148, jsc#ECO-2362, jsc#PM-2069)
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.14.39
  * api-change:``savingsplans``: [``botocore``] Update savingsplans client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.14.38
  * api-change:``sms``: [``botocore``] Update sms client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.14.37
  * api-change:``lex-runtime``: [``botocore``] Update lex-runtime client to latest version
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``personalize-events``: [``botocore``] Update personalize-events client to latest version
- from version 1.14.36
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
- Update BuildRequires and Requires from setup.py
* Thu Aug  6 2020 dmueller@suse.com
- Version update to 1.14.35
  * api-change:``health``: [``botocore``] Update health client to latest version
- from version 1.14.34
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.14.33
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``wafv2``: [``botocore``] Update wafv2 client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime client to latest version
- from version 1.14.32
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``sesv2``: [``botocore``] Update sesv2 client to latest version
- from version 1.14.31
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``firehose``: [``botocore``] Update firehose client to latest version
  * api-change:``servicediscovery``: [``botocore``] Update servicediscovery client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
- from version 1.14.30
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``ivs``: [``botocore``] Update ivs client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
- from version 1.14.29
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``frauddetector``: [``botocore``] Update frauddetector client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
- from version 1.14.28
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``frauddetector``: [``botocore``] Update frauddetector client to latest version
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``mq``: [``botocore``] Update mq client to latest version
- from version 1.14.27
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
- from version 1.14.26
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.14.25
  * api-change:``codeguruprofiler``: [``botocore``] Update codeguruprofiler client to latest version
- from version 1.14.24
  * api-change:``frauddetector``: [``botocore``] Update frauddetector client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``groundstation``: [``botocore``] Update groundstation client to latest version
  * api-change:``fms``: [``botocore``] Update fms client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
- from version 1.14.23
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.14.22
  * enhancement:examples: [``botocore``] Pull in latest examples from EFS.
* Thu Jul 16 2020 adrian.glaubitz@suse.com
- Version update to 1.14.21
  * api-change:``ivs``: [``botocore``] Update ivs client to latest version
- from version 1.14.20
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``wafv2``: [``botocore``] Update wafv2 client to latest version
  * api-change:``ebs``: [``botocore``] Update ebs client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``cloudhsmv2``: [``botocore``] Update cloudhsmv2 client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
- from version 1.14.19
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``forecast``: [``botocore``] Update forecast client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.14.18
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``lakeformation``: [``botocore``] Update lakeformation client to latest version
  * api-change:``efs``: [``botocore``] Update efs client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
- from version 1.14.17
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
- from version 1.14.16
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
- from version 1.14.15
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
- from version 1.14.14
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``codeguru-reviewer``: [``botocore``] Update codeguru-reviewer client to latest version
  * api-change:``comprehendmedical``: [``botocore``] Update comprehendmedical client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.14.13
  * api-change:``codestar-connections``: [``botocore``] Update codestar-connections client to latest version
  * api-change:``codeguruprofiler``: [``botocore``] Update codeguruprofiler client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
- from version 1.14.12
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
- from version 1.14.11
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.14.10
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``backup``: [``botocore``] Update backup client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``honeycode``: [``botocore``] Update honeycode client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
- from version 1.14.9
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.14.8
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``sqs``: [``botocore``] Update sqs client to latest version
- from version 1.14.7
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.14.6
  * api-change:``support``: [``botocore``] Update support client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``meteringmarketplace``: [``botocore``] Update meteringmarketplace client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``sesv2``: [``botocore``] Update sesv2 client to latest version
- from version 1.14.5
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``snowball``: [``botocore``] Update snowball client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
- from version 1.14.4
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``dataexchange``: [``botocore``] Update dataexchange client to latest version
  * api-change:``qldb``: [``botocore``] Update qldb client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``polly``: [``botocore``] Update polly client to latest version
- from version 1.14.3
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``appconfig``: [``botocore``] Update appconfig client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
- Update BuildRequires and Requires from setup.py
* Mon Jun 15 2020 adrian.glaubitz@suse.com
- Version update to 1.14.2
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
- from version 1.14.1
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``iot-data``: [``botocore``] Update iot-data client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.14.0
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``codeartifact``: [``botocore``] Update codeartifact client to latest version
  * api-change:``compute-optimizer``: [``botocore``] Update compute-optimizer client to latest version
  * api-change:``shield``: [``botocore``] Update shield client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``appconfig``: [``botocore``] Update appconfig client to latest version
  * feature:SSO: [``botocore``] Added support for the SSO credential provider. This allows the
    SDK to retrieve temporary AWS credentials from a profile configured to use SSO credentials.
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
- from version 1.13.26
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
- from version 1.13.25
  * api-change:``shield``: [``botocore``] Update shield client to latest version
  * api-change:``servicediscovery``: [``botocore``] Update servicediscovery client to latest version
- from version 1.13.24
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime client to latest version
  * api-change:``sagemaker-runtime``: [``botocore``] Update sagemaker-runtime client to latest version
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
- from version 1.13.23
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``meteringmarketplace``: [``botocore``] Update meteringmarketplace client to latest version
  * api-change:``mediapackage-vod``: [``botocore``] Update mediapackage-vod client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.13.22
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.13.21
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
- from version 1.13.20
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``worklink``: [``botocore``] Update worklink client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
- from version 1.13.19
  * api-change:``marketplace-catalog``: [``botocore``] Update marketplace-catalog client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``qldb-session``: [``botocore``] Update qldb-session client to latest version
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
- from version 1.13.18
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
- from version 1.13.17
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``macie``: [``botocore``] Update macie client to latest version
- from version 1.13.16
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
- from version 1.13.15
  * api-change:``synthetics``: [``botocore``] Update synthetics client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.13.14
  * api-change:``backup``: [``botocore``] Update backup client to latest version
  * api-change:``codedeploy``: [``botocore``] Update codedeploy client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
- from version 1.13.13
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``health``: [``botocore``] Update health client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
- from version 1.13.12
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``qldb``: [``botocore``] Update qldb client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
- from version 1.13.11
  * api-change:``sts``: [``botocore``] Update sts client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
- from version 1.13.10
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
- from version 1.13.9
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``macie2``: [``botocore``] Update macie2 client to latest version
- from version 1.13.8
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * enchancement:Endpoints: [``botocore``] Improved endpoint resolution for clients with unknown regions
- from version 1.13.7
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codeguru-reviewer``: [``botocore``] Update codeguru-reviewer client to latest version
- from version 1.13.6
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi client to latest version
- from version 1.13.5
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``appconfig``: [``botocore``] Update appconfig client to latest version
  * api-change:``logs``: [``botocore``] Update logs client to latest version
- from version 1.13.4
  * api-change:``codestar-connections``: [``botocore``] Update codestar-connections client to latest version
  * api-change:``comprehendmedical``: [``botocore``] Update comprehendmedical client to latest version
- from version 1.13.3
  * api-change:``support``: [``botocore``] Update support client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.13.2
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
- from version 1.13.1
  * api-change:``efs``: [``botocore``] Update efs client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.13.0
  * api-change:``schemas``: [``botocore``] Update schemas client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
  * feature:Exceptions: [``botocore``] Added support for parsing modeled exception fields.
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.12.49
  * api-change:``iotsitewise``: [``botocore``] Update iotsitewise client to latest version
  * api-change:``waf``: [``botocore``] Update waf client to latest version
  * api-change:``waf-regional``: [``botocore``] Update waf-regional client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``servicediscovery``: [``botocore``] Update servicediscovery client to latest version
- from version 1.12.48
  * api-change:``kinesisvideo``: [``botocore``] Update kinesisvideo client to latest version
  * api-change:``kinesis-video-archived-media``: [``botocore``] Update kinesis-video-archived-media client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.12.47
  * bugfix:Resource: fixes `#2361 <https://github.com/boto/boto3/issues/2361>`__
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``dataexchange``: [``botocore``] Update dataexchange client to latest version
  * api-change:``accessanalyzer``: [``botocore``] Update accessanalyzer client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.12.46
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``elastic-inference``: [``botocore``] Update elastic-inference client to latest version
- from version 1.12.45
  * api-change:``mediapackage-vod``: [``botocore``] Update mediapackage-vod client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``ram``: [``botocore``] Update ram client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``firehose``: [``botocore``] Update firehose client to latest version
- from version 1.12.44
  * api-change:``codeguru-reviewer``: [``botocore``] Update codeguru-reviewer client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``fms``: [``botocore``] Update fms client to latest version
- from version 1.12.43
  * api-change:``route53domains``: [``botocore``] Update route53domains client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
- from version 1.12.42
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``synthetics``: [``botocore``] Update synthetics client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
- from version 1.12.41
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``frauddetector``: [``botocore``] Update frauddetector client to latest version
- from version 1.12.40
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``sagemaker-a2i-runtime``: [``botocore``] Update sagemaker-a2i-runtime client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``snowball``: [``botocore``] Update snowball client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``mgh``: [``botocore``] Update mgh client to latest version
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.12.39
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codeguruprofiler``: [``botocore``] Update codeguruprofiler client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``migrationhub-config``: [``botocore``] Update migrationhub-config client to latest version
- Update BuildRequires and Requires from setup.py
* Wed Apr  8 2020 adrian.glaubitz@suse.com
- Version update to 1.12.38 (bsc#1166924, bsc#1168943)
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``codeguru-reviewer``: [``botocore``] Update codeguru-reviewer client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
- from version 1.12.37
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
- from version 1.12.36
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
* Fri Apr  3 2020 adrian.glaubitz@suse.com
- Version update 1.12.35
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.12.34
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
- from version 1.12.33
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``wafv2``: [``botocore``] Update wafv2 client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``elastic-inference``: [``botocore``] Update elastic-inference client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``mediastore``: [``botocore``] Update mediastore client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
  * api-change:``fms``: [``botocore``] Update fms client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``detective``: [``botocore``] Update detective client to latest version
  * api-change:``appconfig``: [``botocore``] Update appconfig client to latest version
- from version 1.12.32
  * api-change:``accessanalyzer``: [``botocore``] Update accessanalyzer client to latest version
- from version 1.12.31
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- from version 1.12.30
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
- from version 1.12.29
  * api-change:``managedblockchain``: [``botocore``] Update managedblockchain client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``application-insights``: [``botocore``] Update application-insights client to latest version
  * api-change:``detective``: [``botocore``] Update detective client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
- from version 1.12.28
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``rds-data``: [``botocore``] Update rds-data client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- Update BuildRequires and Requires from setup.py
* Tue Mar 24 2020 adrian.glaubitz@suse.com
- Version update to 1.12.27
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
- from version 1.12.26
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- from version 1.12.25
  * api-change:``outposts``: [``botocore``] Update outposts client to latest version
  * api-change:``acm``: [``botocore``] Update acm client to latest version
- from version 1.12.24
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
- from version 1.12.23
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.12.22
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
  * bugfix:Stubber: [``botocore``] fixes `#1884 <https://github.com/boto/botocore/issues/1884>`__
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
- from version 1.12.21
  * api-change:``appconfig``: [``botocore``] Update appconfig client to latest version
- from version 1.12.20
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
- from version 1.12.19
  * api-change:``efs``: [``botocore``] Update efs client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
- from version 1.12.18
  * api-change:``serverlessrepo``: [``botocore``] Update serverlessrepo client to latest version
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * enhancement:timezones: [``botocore``] Improved timezone parsing for
    Windows with new fallback method (#1939)
  * api-change:``marketplacecommerceanalytics``: [``botocore``] Update
    marketplacecommerceanalytics client to latest version
- from version 1.12.17
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
- from version 1.12.16
  * api-change:``signer``: [``botocore``] Update signer client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
- from version 1.12.15
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
- from version 1.12.14
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
- from version 1.12.13
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.12.12
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``comprehendmedical``: [``botocore``] Update comprehendmedical client to latest version
- from version 1.12.11
  * api-change:``config``: [``botocore``] Update config client to latest version
- from version 1.12.10
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``sagemaker-a2i-runtime``: [``botocore``] Update sagemaker-a2i-runtime client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``workdocs``: [``botocore``] Update workdocs client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``accessanalyzer``: [``botocore``] Update accessanalyzer client to latest version
  * api-change:``codeguruprofiler``: [``botocore``] Update codeguruprofiler client to latest version
- from version 1.12.9
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator client to latest version
- from version 1.12.8
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
- from version 1.12.7
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``outposts``: [``botocore``] Update outposts client to latest version
- from version 1.12.6
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
  * api-change:``docdb``: [``botocore``] Update docdb client to latest version
  * api-change:``snowball``: [``botocore``] Update snowball client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
- from version 1.12.5
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``wafv2``: [``botocore``] Update wafv2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
- from version 1.12.4
  * api-change:``savingsplans``: [``botocore``] Update savingsplans client to latest version
  * api-change:``appconfig``: [``botocore``] Update appconfig client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
- from version 1.12.3
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
- from version 1.12.2
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.12.1
  * api-change:``cloud9``: [``botocore``] Update cloud9 client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- Update BuildRequires and Requires from setup.py
* Mon Mar 16 2020 tchvatal@suse.com
- Fix build without python2 present
* Mon Feb 17 2020 adrian.glaubitz@suse.com
- Version update to 1.12.0
  * feature:retries: [``botocore``] Add support for retry modes, including ``standard``
    and ``adaptive`` modes (`#1972 <https://github.com/boto/botocore/issues/1972>`__)
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``shield``: [``botocore``] Update shield client to latest version
- from version 1.11.17
  * api-change:``mediapackage-vod``: [``botocore``] Update mediapackage-vod client to latest version
- from version 1.11.16
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``neptune``: [``botocore``] Update neptune client to latest version
- from version 1.11.15
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
- from version 1.11.14
  * api-change:``docdb``: [``botocore``] Update docdb client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
- from version 1.11.13
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.11.12
  * api-change:``ebs``: [``botocore``] Update ebs client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
- from version 1.11.11
  * api-change:``groundstation``: [``botocore``] Update groundstation client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``forecastquery``: [``botocore``] Update forecastquery client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update
    resourcegroupstaggingapi client to latest version
- from version 1.11.10
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- Update BuildRequires and Requires from setup.py
* Thu Jan 30 2020 adrian.glaubitz@suse.com
- Version update to 1.11.9
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
- from version 1.11.8
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
- from version 1.11.7
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``discovery``: [``botocore``] Update discovery client to latest version
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
  * api-change:``marketplacecommerceanalytics``: [``botocore``] Update marketplacecommerceanalytics client to latest version
- from version 1.11.6
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``application-insights``: [``botocore``] Update application-insights client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
- from version 1.11.5
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``neptune``: [``botocore``] Update neptune client to latest version
  * api-change:``cloudhsmv2``: [``botocore``] Update cloudhsmv2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.11.4
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
- from version 1.11.3
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.11.2
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.11.1
  * api-change:``efs``: [``botocore``] Update efs client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``backup``: [``botocore``] Update backup client to latest version
- from version 1.11.0
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * feature:Python: Dropped support for Python 2.6 and 3.3.
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * feature:Python: [``botocore``] Dropped support for Python 2.6 and 3.3.
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.10.50
  * api-change:``logs``: [``botocore``] Update logs client to latest version
- from version 1.10.49
  * api-change:``fms``: [``botocore``] Update fms client to latest version
  * api-change:``translate``: [``botocore``] Update translate client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
- from version 1.10.48
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``mgh``: [``botocore``] Update mgh client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
- from version 1.10.47
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.10.46
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
- from version 1.10.45
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``health``: [``botocore``] Update health client to latest version
  * api-change:``detective``: [``botocore``] Update detective client to latest version
- from version 1.10.44
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
- from version 1.10.43
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``codestar-connections``: [``botocore``] Update codestar-connections client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.10.42
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
- from version 1.10.41
  * api-change:``kinesisanalyticsv2``: [``botocore``] Update kinesisanalyticsv2 client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.10.40
  * api-change:``mq``: [``botocore``] Update mq client to latest version
  * api-change:``comprehendmedical``: [``botocore``] Update comprehendmedical client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.10.39
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``detective``: [``botocore``] Update detective client to latest version
  * api-change:``sesv2``: [``botocore``] Update sesv2 client to latest version
- from version 1.10.38
  * api-change:``accessanalyzer``: [``botocore``] Update accessanalyzer client to latest version
- from version 1.10.37
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.10.36
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
- from version 1.10.35
  * bugfix:s3: [``botocore``] Add stricter validation to s3 control account id parameter.
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
- from version 1.10.34
  * bugfix:s3: [``botocore``] Fixed an issue where the request path was set
    incorrectly if access point name was present in key path.
- Update BuildRequires and Requires from setup.py
* Fri Dec 13 2019 adrian.glaubitz@suse.com
- Convert to single-spec (fate#326950, bsc#1122668, jsc#PM-1447)
* Thu Dec  5 2019 adrian.glaubitz@suse.com
- Version update to 1.10.33
  * api-change:``kinesisvideo``: [``botocore``] Update kinesisvideo client to latest version
  * api-change:``kinesis-video-signaling``: [``botocore``] Update kinesis-video-signaling client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
- from version 1.10.32
  * api-change:``ebs``: [``botocore``] Update ebs client to latest version
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.10.31
  * api-change:``textract``: [``botocore``] Update textract client to latest version
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``outposts``: [``botocore``] Update outposts client to latest version
  * api-change:``kendra``: [``botocore``] Update kendra client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``networkmanager``: [``botocore``] Update networkmanager client to latest version
  * api-change:``compute-optimizer``: [``botocore``] Update compute-optimizer client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``frauddetector``: [``botocore``] Update frauddetector client to latest version
  * api-change:``sagemaker-a2i-runtime``: [``botocore``] Update sagemaker-a2i-runtime client to latest version
  * api-change:``codeguru-reviewer``: [``botocore``] Update codeguru-reviewer client to latest version
  * api-change:``codeguruprofiler``: [``botocore``] Update codeguruprofiler client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
- from version 1.10.30
  * api-change:``accessanalyzer``: [``botocore``] Update accessanalyzer client to latest version
- from version 1.10.29
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``license-manager``: [``botocore``] Update license-manager client to latest version
  * api-change:``imagebuilder``: [``botocore``] Update imagebuilder client to latest version
  * api-change:``schemas``: [``botocore``] Update schemas client to latest version
- from version 1.10.28
  * api-change:``rds-data``: [``botocore``] Update rds-data client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``elastic-inference``: [``botocore``] Update elastic-inference client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``serverlessrepo``: [``botocore``] Update serverlessrepo client to latest version
- from version 1.10.27
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``wafv2``: [``botocore``] Update wafv2 client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``lex-runtime``: [``botocore``] Update lex-runtime client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``iotsecuretunneling``: [``botocore``] Update iotsecuretunneling client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``application-insights``: [``botocore``] Update application-insights client to latest version
  * api-change:``mediapackage-vod``: [``botocore``] Update mediapackage-vod client to latest version
  * api-change:``appconfig``: [``botocore``] Update appconfig client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``kinesisanalyticsv2``: [``botocore``] Update kinesisanalyticsv2 client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``sesv2``: [``botocore``] Update sesv2 client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``ram``: [``botocore``] Update ram client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
- from version 1.10.26
  * api-change:``acm``: [``botocore``] Update acm client to latest version
  * api-change:``autoscaling-plans``: [``botocore``] Update autoscaling-plans client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``mediapackage-vod``: [``botocore``] Update mediapackage-vod client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``sts``: [``botocore``] Update sts client to latest version
  * api-change:``forecast``: [``botocore``] Update forecast client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- from version 1.10.25
  * bugfix:IMDS metadata: [``botocore``] Add 405 case to metadata fetching logic.
- from version 1.10.24
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``connectparticipant``: [``botocore``] Update connectparticipant client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``lex-runtime``: [``botocore``] Update lex-runtime client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``meteringmarketplace``: [``botocore``] Update meteringmarketplace client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
- from version 1.10.23
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``mediastore``: [``botocore``] Update mediastore client to latest version
  * api-change:``cloudtrail``: [``botocore``] Update cloudtrail client to latest version
  * api-change:``mgh``: [``botocore``] Update mgh client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``migrationhub-config``: [``botocore``] Update migrationhub-config client to latest version
  * api-change:``firehose``: [``botocore``] Update firehose client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``discovery``: [``botocore``] Update discovery client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
- from version 1.10.22
  * bugfix:IMDS: [``botocore``] Fix regression in IMDS credential resolution.
    Fixes `#1892 <https://github.com/boto/botocore/issues/1892>`__.
- from version 1.10.21
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
- from version 1.10.20
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``sagemaker-runtime``: [``botocore``] Update sagemaker-runtime client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.10.19
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``logs``: [``botocore``] Update logs client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
- from version 1.10.18
  * api-change:``meteringmarketplace``: [``botocore``] Update meteringmarketplace client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Thu Nov 14 2019 adrian.glaubitz@suse.com
- Version update to 1.10.17
  * api-change:``sesv2``: [``botocore``] Update sesv2 client to latest version
  * api-change:``dataexchange``: [``botocore``] Update dataexchange client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``cloudsearch``: [``botocore``] Update cloudsearch client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
- from version 1.10.16
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``marketplace-catalog``: [``botocore``] Update marketplace-catalog client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
- from version 1.10.15
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
- from version 1.10.14
  * api-change:``cognito-identity``: [``botocore``] Update cognito-identity client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
- from version 1.10.13
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``sso``: [``botocore``] Update sso client to latest version
  * api-change:``sso-oidc``: [``botocore``] Update sso-oidc client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
- from version 1.10.12
  * api-change:``savingsplans``: [``botocore``] Update savingsplans client to latest version
- from version 1.10.11
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``budgets``: [``botocore``] Update budgets client to latest version
  * api-change:``efs``: [``botocore``] Update efs client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``savingsplans``: [``botocore``] Update savingsplans client to latest version
  * api-change:``signer``: [``botocore``] Update signer client to latest version
- from version 1.10.10
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``codestar-notifications``: [``botocore``] Update codestar-notifications client to latest version
- from version 1.10.9
  * api-change:``dax``: [``botocore``] Update dax client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
- from version 1.10.8
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``cloudtrail``: [``botocore``] Update cloudtrail client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
- from version 1.10.7
  * api-change:``support``: [``botocore``] Update support client to latest version
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.10.6
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
- from version 1.10.5
  * api-change:``cloud9``: [``botocore``] Update cloud9 client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
- from version 1.10.4
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.10.3
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
- from version 1.10.2
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
  * enhancement:``sts``: [``botocore``] Add support for configuring the use of regional STS endpoints.
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.10.1
  * api-change:``polly``: [``botocore``] Update polly client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
- from version 1.10.0
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
  * feature:``botocore.vendored.requests``: [``botocore``] Removed vendored version of ``requests`` (`#1829 <https://github.com/boto/botocore/issues/1829>`__)
- from version 1.9.253
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
- from version 1.9.252
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.251
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``marketplacecommerceanalytics``: [``botocore``] Update marketplacecommerceanalytics client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
- from version 1.9.250
  * api-change:``kinesis-video-archived-media``: [``botocore``] Update kinesis-video-archived-media client to latest version
- from version 1.9.249
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Mon Oct 14 2019 adrian.glaubitz@suse.com
- Version update to 1.9.248
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
- from version 1.9.247
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``lex-runtime``: [``botocore``] Update lex-runtime client to latest version
  * api-change:``fms``: [``botocore``] Update fms client to latest version
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
- from version 1.9.246
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.9.245
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``firehose``: [``botocore``] Update firehose client to latest version
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
- from version 1.9.244
  * api-change:``snowball``: [``botocore``] Update snowball client to latest version
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``firehose``: [``botocore``] Update firehose client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``pinpoint-email``: [``botocore``] Update pinpoint-email client to latest version
- from version 1.9.243
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.9.242
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update
    application-autoscaling client to latest version
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
- from version 1.9.241
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
- from version 1.9.240
  * api-change:``docdb``: [``botocore``] Update docdb client to latest version
- from version 1.9.239
  * api-change:``waf``: [``botocore``] Update waf client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``mq``: [``botocore``] Update mq client to latest version
- from version 1.9.238
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.237
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
- from version 1.9.236
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.9.235
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``comprehendmedical``: [``botocore``] Update comprehendmedical client to latest version
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
- from version 1.9.234
  * api-change:``rds-data``: [``botocore``] Update rds-data client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
- from version 1.9.233
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.232
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.231
  * api-change:``ram``: [``botocore``] Update ram client to latest version
  * api-change:``waf-regional``: [``botocore``] Update waf-regional client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
- from version 1.9.230
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
- from version 1.9.229
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.9.228
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``workmailmessageflow``: [``botocore``] Update workmailmessageflow client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.9.227
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
  * api-change:``ses``: [``botocore``] Update ses client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
- from version 1.9.226
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
- from version 1.9.225
  * api-change:``qldb``: [``botocore``] Update qldb client to latest version
  * api-change:``marketplacecommerceanalytics``: [``botocore``] Update
    marketplacecommerceanalytics client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``qldb-session``: [``botocore``] Update qldb-session client to latest version
- from version 1.9.224
  * api-change:``kinesisanalytics``: [``botocore``] Update kinesisanalytics client to latest version
- from version 1.9.223
  * api-change:``config``: [``botocore``] Update config client to latest version
- from version 1.9.222
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
- from version 1.9.221
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update
    resourcegroupstaggingapi client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
- from version 1.9.220
  * api-change:``mq``: [``botocore``] Update mq client to latest version
  * api-change:``apigatewaymanagementapi``: [``botocore``] Update
    apigatewaymanagementapi client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.219
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update
    application-autoscaling client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.218
  * api-change:``sqs``: [``botocore``] Update sqs client to latest version
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.9.217
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.9.216
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
- from version 1.9.215
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``mediapackage-vod``: [``botocore``] Update mediapackage-vod client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
- from version 1.9.214
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Thu Aug 22 2019 adrian.glaubitz@suse.com
- Version update to 1.9.213 (bsc#1146853, bsc#1146854)
  * api-change:``forecast``: [``botocore``] Update forecast client to latest version
  * api-change:``forecastquery``: [``botocore``] Update forecastquery client to latest version
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``sqs``: [``botocore``] Update sqs client to latest version
- from version 1.9.212
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
- from version 1.9.211
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``cur``: [``botocore``] Update cur client to latest version
- from version 1.9.210
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.209
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
- from version 1.9.208
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.207
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
- from version 1.9.206
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- from version 1.9.205
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``lex-runtime``: [``botocore``] Update lex-runtime client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.9.204
  * api-change:``lakeformation``: [``botocore``] Update lakeformation client to latest version
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
- from version 1.9.203
  * api-change:``application-insights``: [``botocore``] Update application-insights client to latest version
- from version 1.9.202
  * api-change:``batch``: [``botocore``] Update batch client to latest version
- from version 1.9.201
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.200
  * api-change:``sts``: [``botocore``] Update sts client to latest version
  * enhancement:Credentials: [``botocore``] Add support for a credential provider that
    handles resolving credentials via STS AssumeRoleWithWebIdentity
- from version 1.9.199
  * api-change:``polly``: [``botocore``] Update polly client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
- from version 1.9.198
  * bugfix:S3: [``botocore``] Fix an issue that would cause S3 list_object_versions to
    sometimes fail parsing responses with certain key values.
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
- from version 1.9.197
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``logs``: [``botocore``] Update logs client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.196
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.9.195
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``sts``: [``botocore``] Update sts client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.9.194
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
- from version 1.9.193
  * api-change:``mq``: [``botocore``] Update mq client to latest version
  * api-change:``shield``: [``botocore``] Update shield client to latest version
- from version 1.9.192
  * bugfix:Dependency: [``botocore``] Fixed dependency issue with broken docutils
    aws/aws-cli`#4332 <https://github.com/boto/botocore/issues/4332>`__
- from version 1.9.191
  * api-change:``sqs``: [``botocore``] Update sqs client to latest version
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
- from version 1.9.190
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``codedeploy``: [``botocore``] Update codedeploy client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.189
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Tue Jul 16 2019 adrian.glaubitz@suse.com
- Version update to 1.9.188
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
- from version 1.9.187
  * api-change:``events``: [``botocore``] Update events client to latest version
- from version 1.9.186
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``glacier``: [``botocore``] Update glacier client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- from version 1.9.185
  * api-change:``efs``: [``botocore``] Update efs client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``kinesis-video-archived-media``: [``botocore``] Update kinesis-video-archived-media client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
  * api-change:``kinesisvideo``: [``botocore``] Update kinesisvideo client to latest version
  * api-change:``waf``: [``botocore``] Update waf client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``waf-regional``: [``botocore``] Update waf-regional client to latest version
- from version 1.9.184
  * api-change:``ce``: [``botocore``] Update ce client to latest version
- from version 1.9.183
  * api-change:``swf``: [``botocore``] Update swf client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.182
  * enhancement:CSM: [``botocore``] Support configuration of the host used in client side metrics via AWS_CSM_HOST
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``mediastore``: [``botocore``] Update mediastore client to latest version
- from version 1.9.181
  * api-change:``docdb``: [``botocore``] Update docdb client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.180
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Fri Jun 28 2019 adrian.glaubitz@suse.com
- Version update to 1.9.179
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``ec2-instance-connect``: [``botocore``] Update ec2-instance-connect client to latest version
- from version 1.9.178
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
- from version 1.9.177
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
- from version 1.9.176
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
- from version 1.9.175
  * api-change:``application-insights``: [``botocore``] Update application-insights client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``service-quotas``: [``botocore``] Update service-quotas client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
- from version 1.9.174
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
  * api-change:``kinesis-video-media``: [``botocore``] Update kinesis-video-media client to latest version
- from version 1.9.173
  * api-change:``health``: [``botocore``] Update health client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``iotevents-data``: [``botocore``] Update iotevents-data client to latest version
  * api-change:``opsworks``: [``botocore``] Update opsworks client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``acm-pca``: [``botocore``] Update acm-pca client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Thu Jun 20 2019 adrian.glaubitz@suse.com
- Version update to 1.9.172
  * api-change:``eks``: [``botocore``] Update eks client to latest version
- from version 1.9.171
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``resourcegroupstaggingapi``: [``botocore``] Update resourcegroupstaggingapi client to latest version
- from version 1.9.170
  * api-change:``neptune``: [``botocore``] Update neptune client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * bugfix:Paginator: [``botocore``] Fixes a bug where pagination tokens with three consecutive
    underscores would result in a parsing failure. Resolves boto/boto3`#1984
    <https://github.com/boto/boto3/issues/1984>`__.
- from version 1.9.169
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
- from version 1.9.168
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
- from version 1.9.167
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Wed Jun 12 2019 adrian.glaubitz@suse.com
- Version update to 1.9.166
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.9.165
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``personalize-runtime``: [``botocore``] Update personalize-runtime client to latest version
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``personalize-events``: [``botocore``] Update personalize-events client to latest version
  * api-change:``personalize``: [``botocore``] Update personalize client to latest version
- from version 1.9.164
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.163
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``logs``: [``botocore``] Update logs client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ses``: [``botocore``] Update ses client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
- from version 1.9.162
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.9.161
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
- from version 1.9.160
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.159
  * api-change:``iotevents-data``: [``botocore``] Update iotevents-data client to latest version
  * api-change:``iotevents``: [``botocore``] Update iotevents client to latest version
  * api-change:``pinpoint-email``: [``botocore``] Update pinpoint-email client to latest version
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``rds-data``: [``botocore``] Update rds-data client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
- from version 1.9.158
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``iotthingsgraph``: [``botocore``] Update iotthingsgraph client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.157
  * api-change:``groundstation``: [``botocore``] Update groundstation client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``waf``: [``botocore``] Update waf client to latest version
  * api-change:``pinpoint-email``: [``botocore``] Update pinpoint-email client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``sts``: [``botocore``] Update sts client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Sat May 25 2019 adrian.glaubitz@suse.com
- Version update to 1.9.156
  * api-change:``mediastore-data``: [``botocore``] Update mediastore-data client to latest version
  * api-change:``codedeploy``: [``botocore``] Update codedeploy client to latest version
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
- from version 1.9.155
  * api-change:``waf-regional``: [``botocore``] Update waf-regional client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.154
  * api-change:``efs``: [``botocore``] Update efs client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``worklink``: [``botocore``] Update worklink client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
  * api-change:``budgets``: [``botocore``] Update budgets client to latest version
- from version 1.9.153
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
- from version 1.9.152
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``meteringmarketplace``: [``botocore``] Update meteringmarketplace client to latest version
  * api-change:``mediapackage-vod``: [``botocore``] Update mediapackage-vod client to latest version
- from version 1.9.151
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
- from version 1.9.150
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.9.149
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * enhancement:Environment Variables: [``botocore``] Ignore env var credentials is values
    are empty (`#1680 <https://github.com/boto/botocore/issues/1680>`__)
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.148
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Tue May 14 2019 adrian.glaubitz@suse.com
- Version update to 1.9.147
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
- from version 1.9.146
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``sts``: [``botocore``] Update sts client to latest version
- from version 1.9.145
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``kinesisanalytics``: [``botocore``] Update kinesisanalytics client to latest version
  * api-change:``kinesisanalyticsv2``: [``botocore``] Update kinesisanalyticsv2 client to latest version
- from version 1.9.144
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
- from version 1.9.143
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``sts``: [``botocore``] Update sts client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
- from version 1.9.142
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.9.141
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
- from version 1.9.140
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.139
  * api-change:``neptune``: [``botocore``] Update neptune client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``managedblockchain``: [``botocore``] Update managedblockchain client to latest version
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
- from version 1.9.138
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.137
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
- from version 1.9.136
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``inspector``: [``botocore``] Update inspector client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
- from version 1.9.135
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
  * api-change:``textract``: [``botocore``] Update textract client to latest version
- from version 1.9.134
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
- from version 1.9.133
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``worklink``: [``botocore``] Update worklink client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``discovery``: [``botocore``] Update discovery client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.9.132
  * api-change:``polly``: [``botocore``] Update polly client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.131
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``mq``: [``botocore``] Update mq client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
- from version 1.9.130
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``iot1click-devices``: [``botocore``] Update iot1click-devices client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.9.129
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
- from version 1.9.128
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Wed Apr  3 2019 adrian.glaubitz@suse.com
- Version update to 1.9.127
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``acm``: [``botocore``] Update acm client to latest version
- from version 1.9.126
  * api-change:``emr``: [``botocore``] Update emr client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.9.125
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
- from version 1.9.124
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``pinpoint-email``: [``botocore``] Update pinpoint-email client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
- from version 1.9.123
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.9.122
  * api-change:``workmail``: [``botocore``] Update workmail client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.9.121
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``fms``: [``botocore``] Update fms client to latest version
  * api-change:``iot1click-devices``: [``botocore``] Update iot1click-devices client to latest version
- from version 1.9.120
  * api-change:``iot1click-projects``: [``botocore``] Update iot1click-projects client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
- from version 1.9.119
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
- from version 1.9.118
  * api-change:``cognito-identity``: [``botocore``] Update cognito-identity client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``meteringmarketplace``: [``botocore``] Update meteringmarketplace
    client to latest version
- from version 1.9.117
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
- from version 1.9.116
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``chime``: [``botocore``] Update chime client to latest version
- from version 1.9.115
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``acm``: [``botocore``] Update acm client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``acm-pca``: [``botocore``] Update acm-pca client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.9.114
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``logs``: [``botocore``] Update logs client to latest version
- from version 1.9.113
  * api-change:``serverlessrepo``: [``botocore``] Update serverlessrepo client to latest version
- from version 1.9.112
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- from version 1.9.111
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.9.110
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.109
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.108
  * api-change:``textract``: [``botocore``] Update textract client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``codedeploy``: [``botocore``] Update codedeploy client to latest version
- from version 1.9.107
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.9.106
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``autoscaling-plans``: [``botocore``] Update autoscaling-plans client to latest version
- from version 1.9.105
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update
    application-autoscaling client to latest version
- from version 1.9.104
  * api-change:``waf-regional``: [``botocore``] Update waf-regional client to latest version
  * api-change:``waf``: [``botocore``] Update waf client to latest version
- from version 1.9.103
  * api-change:``discovery``: [``botocore``] Update discovery client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``cur``: [``botocore``] Update cur client to latest version
- from version 1.9.102
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``mediastore``: [``botocore``] Update mediastore client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
- from version 1.9.101
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``cloud9``: [``botocore``] Update cloud9 client to latest version
- from version 1.9.100
  * api-change:``kinesis-video-archived-media``: [``botocore``] Update
    kinesis-video-archived-media client to latest version
  * api-change:``workdocs``: [``botocore``] Update workdocs client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``kinesisvideo``: [``botocore``] Update kinesisvideo client to latest version
  * api-change:``kinesis-video-media``: [``botocore``] Update
    kinesis-video-media client to latest version
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
- from version 1.9.99
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.9.98
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
  * enhancement:Paginator: [``botocore``] Add additional paginators for CloudFormation
  * api-change:``efs``: [``botocore``] Update efs client to latest version
- from version 1.9.97
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
- Update BuildRequires and Requires in spec file from setup.py
* Wed Mar 13 2019 tchvatal@suse.com
- Do not use python_module in requires, it breaks up resolver
* Tue Mar  5 2019 sean.marlow@suse.com
- Fix botocore version requirement.
* Sat Feb 16 2019 jayvdb@gmail.com
- Increase maximum version of s3transfer to include 0.2.x, as 0.2.0
  is the release currently in the rolling release area, making boto3
  builds broken.
- Add versions to build dependencies to avoid building uninstallable
  release.
- Version update to 1.9.96
  * api-change:chime: [botocore] Update chime client to latest version
  * api-change:application-autoscaling: [botocore] Update application-autoscaling client to latest version
  * api-change:iot: [botocore] Update iot client to latest version
- from 1.9.95
  * api-change:kinesisvideo: [botocore] Update kinesisvideo client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
- from 1.9.94
  * api-change:rekognition: [botocore] Update rekognition client to latest version
  * api-change:mediatailor: [botocore] Update mediatailor client to latest version
  * api-change:efs: [botocore] Update efs client to latest version
* Wed Feb 13 2019 adrian.glaubitz@suse.com
- Version update to 1.9.93
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
- from version 1.9.92
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
- from version 1.9.91
  * api-change:``discovery``: [``botocore``] Update discovery client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
- from version 1.9.90
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
- from version 1.9.89
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
- from version 1.9.88
  * api-change:``shield``: [``botocore``] Update shield client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.87
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling
    client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
- from version 1.9.86
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
- from version 1.9.85
  * api-change:``logs``: [``botocore``] Update logs client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``sms-voice``: [``botocore``] Update sms-voice client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
- Update Requires in spec file from setup.py
* Thu Jan 24 2019 adrian.glaubitz@suse.com
- Version update to 1.9.84
  * api-change:``worklink``: [``botocore``] Update worklink client to latest version
  * api-change:``apigatewaymanagementapi``: [``botocore``]
    Update apigatewaymanagementapi client to latest version
  * api-change:``acm-pca``: [``botocore``] Update acm-pca client to latest version
- from version 1.9.83
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``discovery``: [``botocore``] Update discovery client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``fms``: [``botocore``] Update fms client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.9.82
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.81
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- from version 1.9.80
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``backup``: [``botocore``] Update backup client to latest version
- from version 1.9.79
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.9.78
  * api-change:``rds-data``: [``botocore``] Update rds-data client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
- from version 1.9.77
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codedeploy``: [``botocore``] Update codedeploy client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.9.76
  * api-change:``docdb``: [``botocore``] Update docdb client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
- from version 1.9.75
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
- Update Requires in spec file from setup.py
* Sun Jan  6 2019 adrian.glaubitz@suse.com
- Version update to 1.9.74
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
- from version 1.9.73
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
- from version 1.9.72
  * enhancement:Paginator: [``botocore``] Added over 400 new paginators.
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
- from version 1.9.71
  * api-change:``acm-pca``: [``botocore``] Update acm-pca client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``sms-voice``: [``botocore``] Update sms-voice client to latest version
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
- from version 1.9.70
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * enhancement:EndpointDiscovery: [``botocore``] Add a config option,
    ``endpoint_discovery_enabled``, for automatically discovering endpoints
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``firehose``: [``botocore``] Update firehose client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
- from version 1.9.69
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``waf-regional``: [``botocore``] Update waf-regional client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``waf``: [``botocore``] Update waf client to latest version
- from version 1.9.68
  * api-change:``apigatewayv2``: [``botocore``] Update apigatewayv2 client to latest version
  * bugfix:Credentials: [``botocore``] Fixes an issue where credentials would be checked when
    creating an anonymous client. Fixes `#1472 <https://github.com/boto/botocore/issues/1472>`__
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator client to latest version
  * enhancement:StreamingBody: [``botocore``] Support iterating lines from a streaming response
    body with CRLF line endings
  * api-change:``apigatewaymanagementapi``: [``botocore``] Update apigatewaymanagementapi
    client to latest version
- from version 1.9.67
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``ecr``: [``botocore``] Update ecr client to latest version
- from version 1.9.66
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
- from version 1.9.65
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``pinpoint-email``: [``botocore``] Update pinpoint-email client to latest version
- from version 1.9.64
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
- from version 1.9.63
  * api-change:``mediastore``: [``botocore``] Update mediastore client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
- from version 1.9.62
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * enhancement:AssumeRole: [``botocore``] Add support for duration_seconds when assuming
    a role in the config file (`#1600 <https://github.com/boto/botocore/issues/1600>`__).
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
- from version 1.9.61
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.60
  * api-change:``mq``: [``botocore``] Update mq client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
- from version 1.9.59
  * api-change:``health``: [``botocore``] Update health client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.9.58
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- Update Requires in spec file from setup.py
* Mon Dec  3 2018 adrian.glaubitz@suse.com
- Version update to 1.9.57 (bsc#1118021, bsc#1118024, bsc#1118027)
  * bugfix:s3: [``botocore``] Add md5 header injection to new operations that require it
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- from version 1.9.56
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``stepfunctions``: [``botocore``] Update stepfunctions client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``serverlessrepo``: [``botocore``] Update serverlessrepo client to latest version
  * api-change:``kafka``: [``botocore``] Update kafka client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
- Update Requires in spec file from setup.py
* Thu Nov 29 2018 adrian.glaubitz@suse.com
- Version update to 1.9.55
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``appmesh``: [``botocore``] Update appmesh client to latest version
  * api-change:``license-manager``: [``botocore``] Update license-manager client to latest version
  * api-change:``servicediscovery``: [``botocore``] Update servicediscovery client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
- from version 1.9.54
  * api-change:``securityhub``: [``botocore``] Update securityhub client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``fsx``: [``botocore``] Update fsx client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
- from version 1.9.53
  * api-change:``meteringmarketplace``: [``botocore``] Update meteringmarketplace client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codedeploy``: [``botocore``] Update codedeploy client to latest version
  * api-change:``translate``: [``botocore``] Update translate client to latest version
  * api-change:``logs``: [``botocore``] Update logs client to latest version
  * api-change:``kinesisanalytics``: [``botocore``] Update kinesisanalytics client to latest version
  * api-change:``comprehendmedical``: [``botocore``] Update comprehendmedical client to latest version
  * api-change:``mediaconnect``: [``botocore``] Update mediaconnect client to latest version
  * api-change:``kinesisanalyticsv2``: [``botocore``] Update kinesisanalyticsv2 client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.52
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``sms``: [``botocore``] Update sms client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
  * api-change:``kms``: [``botocore``] Update kms client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``globalaccelerator``: [``botocore``] Update globalaccelerator client to latest version
- from version 1.9.51
  * api-change:``amplify``: [``botocore``] Update amplify client to latest version
  * api-change:``transfer``: [``botocore``] Update transfer client to latest version
  * api-change:``snowball``: [``botocore``] Update snowball client to latest version
  * api-change:``robomaker``: [``botocore``] Update robomaker client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``datasync``: [``botocore``] Update datasync client to latest version
- from version 1.9.50
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- from version 1.9.49
  * api-change:``autoscaling-plans``: [``botocore``] Update autoscaling-plans client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``rds-data``: [``botocore``] Update rds-data client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``quicksight``: [``botocore``] Update quicksight client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
- from version 1.9.48
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``workdocs``: [``botocore``] Update workdocs client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``cloudtrail``: [``botocore``] Update cloudtrail client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
- from version 1.9.47
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.9.46
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``sms-voice``: [``botocore``] Update sms-voice client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``s3control``: [``botocore``] Update s3control client to latest version
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``ram``: [``botocore``] Update ram client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``route53resolver``: [``botocore``] Update route53resolver client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``iam``: [``botocore``] Update iam client to latest version
- from version 1.9.45
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.44
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``budgets``: [``botocore``] Update budgets client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
- from version 1.9.43
  * api-change:``polly``: [``botocore``] Update polly client to latest version
  * api-change:``batch``: [``botocore``] Update batch client to latest version
  * api-change:``firehose``: [``botocore``] Update firehose client to latest version
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
  * api-change:``budgets``: [``botocore``] Update budgets client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.42
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
- from version 1.9.41
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``events``: [``botocore``] Update events client to latest version
- from version 1.9.40
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.39
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``pinpoint-email``: [``botocore``] Update pinpoint-email client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``waf-regional``: [``botocore``] Update waf-regional client to latest version
  * bugfix:session config: [``botocore``] Added the default session configuration
    tuples back to session.session_vars_map.
- Update Requires in spec file from setup.py
* Wed Nov  7 2018 rjschwei@suse.com
- Fix build for openSUSE Leap 42.3
  + urllib3 needs the ssl module, which in Leap 42.3 is delivered by python
    and not python-base. Set explicit build dependency on python
* Tue Nov  6 2018 adrian.glaubitz@suse.com
- Version update to 1.9.38
  * api-change:``eks``: [``botocore``] Update eks client to latest version
  * enhancement:Configuration: [``botocore``] Added new configuration provider
    methods allowing for more flexibility in how a botocore session loads a
    particular configuration value.
  * api-change:``serverlessrepo``: [``botocore``] Update serverlessrepo client
    to latest version
- Update Requires in spec file from setup.py
* Mon Nov  5 2018 adrian.glaubitz@suse.com
- Version update to 1.9.37
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
  * api-change:``clouddirectory``: [``botocore``] Update clouddirectory client to latest version
- from version 1.9.36
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * enhancement:Exceptions: [``botocore``] Add the ability to pickle botocore
    exceptions (`834 <https://github.com/boto/botocore/issues/834>`__)
- from version 1.9.35
  * api-change:``mediastore-data``: [``botocore``] Update mediastore-data client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
- from version 1.9.34
  * api-change:``chime``: [``botocore``] Update chime client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
- from 1.9.33
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.9.32
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.31
  * api-change:``codestar``: [``botocore``] Update codestar client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
- from version 1.9.30
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.29
  * api-change:``inspector``: [``botocore``] Update inspector client to latest version
  * api-change:``shield``: [``botocore``] Update shield client to latest version
- from version 1.9.28
  * api-change:``workspaces``: [``botocore``] Update workspaces client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.9.27
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
  * api-change:``route53``: [``botocore``] Update route53 client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
- from version 1.9.26
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
- from version 1.9.25
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``lightsail``: [``botocore``] Update lightsail client to latest version
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
- from version 1.9.24
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- from version 1.9.23
  * api-change:``cloudtrail``: [``botocore``] Update cloudtrail client to latest version
- from version 1.9.22
  * api-change:``athena``: [``botocore``] Update athena client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
- from version 1.9.21
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
- from version 1.9.20
  * enhancement:TLS: [``botocore``] Added support for configuring a client
    certificate and key when establishing TLS connections.
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * bugfix:InstanceMetadataFetcher: [``botocore``] Fix failure to retry
    on empty credentials and invalid JSON returned from IMDS
    `1049 <https://github.com/boto/botocore/issues/1049>`__
    `1403 <https://github.com/boto/botocore/issues/1403>`__
- from version 1.9.19
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``iot-jobs-data``: [``botocore``] Update iot-jobs-data client to latest version
- from version 1.9.18
  * api-change:``ds``: [``botocore``] Update ds client to latest version
- from version 1.9.17
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * enhancement:HTTP Session: [``botocore``] Added the ability to enable TCP Keepalive
    via the shared config file's ``tcp_keepalive`` option.
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
- from version 1.9.16
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
- from version 1.9.15
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
  * api-change:``guardduty``: [``botocore``] Update guardduty client to latest version
- from version 1.9.14
  * api-change:``codestar``: [``botocore``] Update codestar client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.13
  * api-change:``mq``: [``botocore``] Update mq client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * enhancement:Event: [``botocore``] Add the `before-send` event which allows finalized
    requests to be inspected before being sent across the wire and allows for custom
    responses to be returned.
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
- from version 1.9.12
  * api-change:``sqs``: [``botocore``] Update sqs client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.11
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
- from version 1.9.10
  * api-change:``connect``: [``botocore``] Update connect client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.9.9
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.9.8
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``ds``: [``botocore``] Update ds client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.9.7
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
- from version 1.9.6
  * bugfix:Serialization: [``botocore``] Fixes `#1557
    <https://github.com/boto/botocore/issues/1557>`__. Fixed a regression
    in serialization where request bodies would be improperly encoded.
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- from version 1.9.5
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``elastictranscoder``: [``botocore``] Update elastictranscoder client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``cloudwatch``: [``botocore``] Update cloudwatch client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``elasticache``: [``botocore``] Update elasticache client to latest version
- from version 1.9.4
  * enhancement:s3: [``botocore``] Adds encoding and decoding handlers for
    ListObjectsV2 `#1552 <https://github.com/boto/botocore/issues/1552>`__
  * api-change:``polly``: [``botocore``] Update polly client to latest version
- from version 1.9.3
  * api-change:``ses``: [``botocore``] Update ses client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``fms``: [``botocore``] Update fms client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
- from version 1.9.2
  * api-change:``opsworkscm``: [``botocore``] Update opsworkscm client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.9.1
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``cloudhsmv2``: [``botocore``] Update cloudhsmv2 client to latest version
- from version 1.9.0
  * api-change:``logs``: [``botocore``] Update logs client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * feature:Events: [``botocore``] This migrates the event system to using sevice
    ids instead of either client name or endpoint prefix. This prevents issues
    that might arise when a service changes their endpoint prefix, also fixes a
    long-standing bug where you could not register an event to a particular service
    if it happened to share its endpoint prefix with another service (e.g.
    ``autoscaling`` and ``application-autoscaling`` both use the endpoint prefix
    ``autoscaling``). Please see the `upgrade notes <https://botocore.amazonaws.com/
    v1/documentation/api/latest/index.html#upgrade-notes>`_ to determine if you are
    impacted and how to proceed if you are.
  * feature:Events: This migrates the event system to using sevice ids instead of
    either client name or endpoint prefix. This prevents issues that might arise when
    a service changes their endpoint prefix, also fixes a long-standing bug where you
    could not register an event to a particular service if it happened to share its
    endpoint prefix with another service (e.g. ``autoscaling`` and ``application-autoscaling``
    both use the endpoint prefix ``autoscaling``). Please see the `upgrade notes
    <https://boto3.amazonaws.com/v1/documentation/api/latest/guide/upgrading.html>`_
    to determine if you are impacted and how to proceed if you are.
- from version 1.8.9
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``codecommit``: [``botocore``] Update codecommit client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.8.8
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``elb``: [``botocore``] Update elb client to latest version
- from version 1.8.7
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- from version 1.8.6
  * api-change:``waf-regional``: [``botocore``] Update waf-regional client to latest version
  * api-change:``waf``: [``botocore``] Update waf client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
- from version 1.8.5
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * bugfix:signing: [``botocore``] Fix an issue where mixed endpoint casing could cause a SigV4 signature mismatch.
- from version 1.8.4
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``sagemaker-runtime``: [``botocore``] Update sagemaker-runtime client to latest version
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
- from version 1.8.3
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``xray``: [``botocore``] Update xray client to latest version
- from version 1.8.2
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``signer``: [``botocore``] Update signer client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
- Update Requires in spec file from setup.py
* Wed Sep 12 2018 adrian.glaubitz@suse.com
- Version update to 1.8.1
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.8.0
  * api-change:``events``: [``botocore``] Update events client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * feature:urllib3: [``botocore``] The vendored version of requests and urllib3 are no longer being used and botocore now has a direct dependency on newer versions of upstream urllib3.
- from version 1.7.84
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
  * api-change:``lex-models``: [``botocore``] Update lex-models client to latest version
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.7.83
  * api-change:``snowball``: [``botocore``] Update snowball client to latest version
- from version 1.7.82
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
- from version 1.7.81
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
- from version 1.7.80
  * api-change:``dax``: [``botocore``] Update dax client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- from version 1.7.79
  * api-change:``discovery``: [``botocore``] Update discovery client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.7.78
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
- from version 1.7.77
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``autoscaling``: [``botocore``] Update autoscaling client to latest version
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
- from version 1.7.76
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
- Replace vendored version of six from botocore with upstream version
- Update Requires in spec file from setup.py
* Mon Aug 13 2018 adrian.glaubitz@suse.com
- Version update to 1.7.75
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.7.74
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``dax``: [``botocore``] Update dax client to latest version
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.7.73
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.7.72
  * api-change:``logs``: [``botocore``] Update logs client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
- from version 1.7.71
  * api-change:``health``: [``botocore``] Update health client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
- from version 1.7.70
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
- from version 1.7.69
  * api-change:``polly``: [``botocore``] Update polly client to latest version
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``kinesis``: [``botocore``] Update kinesis client to latest version
  * api-change:``resource-groups``: [``botocore``] Update resource-groups client to latest version
- from version 1.7.68
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
- from version 1.7.67
  * api-change:``kms``: [``botocore``] Update kms client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``es``: [``botocore``] Update es client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``connect``: [``botocore``] Update connect client to latest version
- from version 1.7.66
  * api-change:``directconnect``: [``botocore``] Update directconnect client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``cloudhsmv2``: [``botocore``] Update cloudhsmv2 client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``mq``: [``botocore``] Update mq client to latest version
  * enhancment:Timestamp Serialization: [``botocore``] Support explicit timestamp serialization per timestamp shape.
  * api-change:``glacier``: [``botocore``] Update glacier client to latest version
- from version 1.7.65
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``greengrass``: [``botocore``] Update greengrass client to latest version
  * api-change:``inspector``: [``botocore``] Update inspector client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
- from version 1.7.64
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
- from version 1.7.63
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
- Update Requires in spec file from setup.py
* Sun Jul 22 2018 adrian.glaubitz@suse.com
- Version update to 1.7.62
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
- from version 1.7.61
  * api-change:``mediapackage``: [``botocore``] Update mediapackage client to latest version
- from version 1.7.60
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
- from version 1.7.59
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``polly``: [``botocore``] Update polly client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``snowball``: [``botocore``] Update snowball client to latest version
- from version 1.7.58
  * api-change:``kinesisvideo``: [``botocore``] Update kinesisvideo client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``kinesis-video-archived-media``: [``botocore``] Update kinesis-video-archived-media client to latest version
- from version 1.7.57
  * api-change:``iam``: [``botocore``] Update iam client to latest version
  * api-change:``dlm``: [``botocore``] Update dlm client to latest version
  * api-change:``appsync``: [``botocore``] Update appsync client to latest version
  * api-change:``efs``: [``botocore``] Update efs client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``emr``: [``botocore``] Update emr client to latest version
- from version 1.7.56
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
- from version 1.7.55
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
  * api-change:``opsworks``: [``botocore``] Update opsworks client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
- from version 1.7.54
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
- from version 1.7.53
  * api-change:``application-autoscaling``: [``botocore``] Update application-autoscaling client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
  * api-change:``dms``: [``botocore``] Update dms client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``transcribe``: [``botocore``] Update transcribe client to latest version
- from version 1.7.52
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``serverlessrepo``: [``botocore``] Update serverlessrepo client to latest version
- from version 1.7.51
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``pinpoint``: [``botocore``] Update pinpoint client to latest version
- from version 1.7.50
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``acm``: [``botocore``] Update acm client to latest version
- from version 1.7.49
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
- from version 1.7.48
  * api-change:``elasticbeanstalk``: [``botocore``] Update elasticbeanstalk client to latest version
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``lambda``: [``botocore``] Update lambda client to latest version
- from version 1.7.47
  * api-change:``cloudfront``: [``botocore``] Update cloudfront client to latest version
  * api-change:``comprehend``: [``botocore``] Update comprehend client to latest version
  * api-change:``codepipeline``: [``botocore``] Update codepipeline client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * enhancement:StreamingResponses: [``botocore``] Add ``iter_lines()`` and ``iter_chunks()`` to streaming responses (`#1195 <https://github.com/boto/botocore/issues/1195>`__)
- from version 1.7.46
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``s3``: [``botocore``] Update s3 client to latest version
  * api-change:``inspector``: [``botocore``] Update inspector client to latest version
- from version 1.7.45
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``alexaforbusiness``: [``botocore``] Update alexaforbusiness client to latest version
- from version 1.7.44
  * api-change:``clouddirectory``: [``botocore``] Update clouddirectory client to latest version
- from version 1.7.43
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``macie``: [``botocore``] Update macie client to latest version
  * api-change:``neptune``: [``botocore``] Update neptune client to latest version
- from version 1.7.42 (bsc#1075263)
  * api-change:``acm-pca``: [``botocore``] Update acm-pca client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.7.41
  * api-change:``rekognition``: [``botocore``] Update rekognition client to latest version
- Update Requires in spec file from setup.py
* Tue Jun 19 2018 adrian.glaubitz@suse.com
- Version update to 1.7.40
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
- from version 1.7.39
  * api-change:``iotanalytics``: [``botocore``] Update iotanalytics client to latest version
  * api-change:``dynamodb``: [``botocore``] Update dynamodb client to latest version
  * api-change:``apigateway``: [``botocore``] Update apigateway client to latest version
- from version 1.7.38
  * api-change:``ssm``: [``botocore``] Update ssm client to latest version
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
- from version 1.7.37
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
  * api-change:``devicefarm``: [``botocore``] Update devicefarm client to latest version
- from version 1.7.36
  * api-change:``storagegateway``: [``botocore``] Update storagegateway client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``clouddirectory``: [``botocore``] Update clouddirectory client to latest version
- from version 1.7.35
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
- from version 1.7.34
  * api-change:``medialive``: [``botocore``] Update medialive client to latest version
- from version 1.7.33
  * api-change:``polly``: [``botocore``] Update polly client to latest version
  * api-change:``ce``: [``botocore``] Update ce client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``shield``: [``botocore``] Update shield client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
- from version 1.7.32
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``sagemaker``: [``botocore``] Update sagemaker client to latest version
  * api-change:``mgh``: [``botocore``] Update mgh client to latest version
  * api-change:``mediaconvert``: [``botocore``] Update mediaconvert client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``eks``: [``botocore``] Update eks client to latest version
- from version 1.7.31
  * api-change:``ds``: [``botocore``] Update ds client to latest version
  * api-change:``mediatailor``: [``botocore``] Update mediatailor client to latest version
  * api-change:``sns``: [``botocore``] Update sns client to latest version
  * api-change:``redshift``: [``botocore``] Update redshift client to latest version
  * api-change:``iot``: [``botocore``] Update iot client to latest version
- from version 1.7.30
  * api-change:``neptune``: [``botocore``] Update neptune client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
- from version 1.7.29
  * api-change:``pi``: [``botocore``] Update pi client to latest version
- from version 1.7.28
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``config``: [``botocore``] Update config client to latest version
  * api-change:``appstream``: [``botocore``] Update appstream client to latest version
  * api-change:``glue``: [``botocore``] Update glue client to latest version
- from version 1.7.27
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``rds``: [``botocore``] Update rds client to latest version
  * api-change:``elbv2``: [``botocore``] Update elbv2 client to latest version
- from version 1.7.26
  * api-change:``inspector``: [``botocore``] Update inspector client to latest version
  * enhancement:Credentials: [``botocore``] Disable proxy configuration when fetching container credentials
  * api-change:``ecs``: [``botocore``] Update ecs client to latest version
- from version 1.7.25
  * api-change:``cloudformation``: [``botocore``] Update cloudformation client to latest version
- from version 1.7.24
  * api-change:``iot``: [``botocore``] Update iot client to latest version
  * api-change:``ses``: [``botocore``] Update ses client to latest version
- from version 1.7.23
  * api-change:``ec2``: [``botocore``] Update ec2 client to latest version
  * api-change:``cognito-idp``: [``botocore``] Update cognito-idp client to latest version
  * api-change:``codedeploy``: [``botocore``] Update codedeploy client to latest version
- from version 1.7.22
  * api-change:``servicecatalog``: [``botocore``] Update servicecatalog client to latest version
  * api-change:``secretsmanager``: [``botocore``] Update secretsmanager client to latest version
- from version 1.7.21
  * api-change:``config``: [``botocore``] Update config client to latest version
- from version 1.7.20
  * api-change:``organizations``: [``botocore``] Update organizations client to latest version
  * api-change:``iot1click-devices``: [``botocore``] Update iot1click-devices client to latest version
  * api-change:``codebuild``: [``botocore``] Update codebuild client to latest version
  * api-change:``iot1click-projects``: [``botocore``] Update iot1click-projects client to latest version
- from version 1.7.19
  * api-change:``firehose``: [``botocore``] Update firehose client to latest version
- from version 1.7.18
  * api-change:``gamelift``: [``botocore``] Update gamelift client to latest version
- Update Requires in spec file from setup.py
* Thu May 10 2018 tchvatal@suse.com
- Version update to 1.10.17:
  * api-change:rds: [botocore] Update rds client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
  * api-change:budgets: [botocore] Update budgets client to latest version
  * api-change:rds: [botocore] Update rds client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
  * api-change:alexaforbusiness: [botocore] Update alexaforbusiness client to latest version
  * api-change:s3: [botocore] Update s3 client to latest version
  * api-change:budgets: [botocore] Update budgets client to latest version
  * api-change:es: [botocore] Update es client to latest version
  * api-change:guardduty: [botocore] Update guardduty client to latest version
  * api-change:config: [botocore] Update config client to latest version
  * api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  * api-change:appsync: [botocore] Update appsync client to latest version
  * api-change:acm: [botocore] Update acm client to latest version
  * api-change:codepipeline: [botocore] Update codepipeline client to latest version
  * api-change:ssm: [botocore] Update ssm client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
  * api-change:guardduty: [botocore] Update guardduty client to latest version
  * api-change:alexaforbusiness: [botocore] Update alexaforbusiness client to latest version
  * api-change:route53domains: [botocore] Update route53domains client to latest version
  * api-change:workspaces: [botocore] Update workspaces client to latest version
  * api-change:sagemaker: [botocore] Update sagemaker client to latest version
  * api-change:dynamodb: [botocore] Update dynamodb client to latest version
  * api-change:glacier: [botocore] Update glacier client to latest version
  * api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  * api-change:rekognition: [botocore] Update rekognition client to latest version
  * api-change:xray: [botocore] Update xray client to latest version
  * api-change:codedeploy: [botocore] Update codedeploy client to latest version
  * api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  * api-change:elasticbeanstalk: [botocore] Update elasticbeanstalk client to latest version
  * api-change:iotanalytics: [botocore] Update iotanalytics client to latest version
  * api-change:iot: [botocore] Update iot client to latest version
  * api-change:autoscaling-plans: [botocore] Update autoscaling-plans client to latest version
  * api-change:medialive: [botocore] Update medialive client to latest version
  * api-change:firehose: [botocore] Update firehose client to latest version
  * api-change:ce: [botocore] Update ce client to latest version
  * api-change:codepipeline: [botocore] Update codepipeline client to latest version
  * api-change:ssm: [botocore] Update ssm client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
  * api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  * api-change:rds: [botocore] Update rds client to latest version
  * api-change:devicefarm: [botocore] Update devicefarm client to latest version
  * bugfix:dynamodb: Fixes a bug causing dynamodb operations with no output to throw errors.
* Tue May  8 2018 tchvatal@suse.com
- Really enable unittests
* Sun Apr 15 2018 tchvatal@suse.com
- Version update to 1.7.4:
  api-change:ssm: [botocore] Update ssm client to latest version
  api-change:workmail: [botocore] Update workmail client to latest version
  api-change:dms: [botocore] Update dms client to latest version
  api-change:mediapackage: [botocore] Update mediapackage client to latest version
  api-change:glue: [botocore] Update glue client to latest version
  api-change:clouddirectory: [botocore] Update clouddirectory client to latest version
* Fri Apr  6 2018 sebix+novell.com@sebix.at
- update to version 1.7.2
  - api-change:batch: [botocore] Update batch client to latest version
- update to version 1.7.1
  - enhancementshield [botocore] Added paginator for list_protections operation.
  - api-change:ssm: [botocore] Update ssm client to latest version
- update to version 1.7.0
  - api-change:s3: [botocore] Update s3 client to latest version
  - api-change:sagemaker: [botocore] Update sagemaker client to latest version
  - api-change:acm: [botocore] Update acm client to latest version
  - api-change:config: [botocore] Update config client to latest version
  - api-change:transcribe: [botocore] Update transcribe client to latest version
  - api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  - api-change:acm-pca: [botocore] Update acm-pca client to latest version
  - api-change:cloudwatch: [botocore] Update cloudwatch client to latest version
  - feature:s3: Add support for S3 Select. Amazon S3 Select is an Amazon S3 feature that makes it easy to retrieve specific data from the contents of an object using simple SQL expressions without having to retrieve the entire object. With this release of the Amazon S3 SDK, S3 Select API (SelectObjectContent) is now generally available in all public regions. This release supports retrieval of a subset of data using SQL clauses, like SELECT and WHERE, from delimited text files and JSON objects in Amazon S3 through the SelectObjectContent API available in AWS S3 SDK.
  - api-change:fms: [botocore] Update fms client to latest version
- update to version 1.6.23
  - api-change:lambda: [botocore] Update lambda client to latest version
  - api-change:devicefarm: [botocore] Update devicefarm client to latest version
  - api-change:translate: [botocore] Update translate client to latest version
- update to version 1.6.22
  - api-change:cloudfront: [botocore] Update cloudfront client to latest version
  - api-change:apigateway: [botocore] Update apigateway client to latest version
  - api-change:es: [botocore] Update es client to latest version
- update to version 1.6.21
  - api-change:connect: [botocore] Update connect client to latest version
  - api-change:acm: [botocore] Update acm client to latest version
- update to version 1.6.20
  - api-change:greengrass: [botocore] Update greengrass client to latest version
  - api-change:cloudformation: [botocore] Update cloudformation client to latest version
  - api-change:ssm: [botocore] Update ssm client to latest version
  - api-change:alexaforbusiness: [botocore] Update alexaforbusiness client to latest version
- update to version 1.6.19
  - api-change:mturk: [botocore] Update mturk client to latest version
  - api-change:sts: [botocore] Update sts client to latest version
  - api-change:iam: [botocore] Update iam client to latest version
- update to version 1.6.18
  - api-change:acm: [botocore] Update acm client to latest version
- update to version 1.6.17
  - api-change:dynamodb: [botocore] Update dynamodb client to latest version
  - bugfix:s3: [botocore] Fix bug where invalid head_object requests would cause an infinite loop (alternate fix to #1400)
- update to version 1.6.16
  - api-change:rds: [botocore] Update rds client to latest version
- update to version 1.6.15
  - api-change:ecs: [botocore] Update ecs client to latest version
  - api-change:appstream: [botocore] Update appstream client to latest version
  - api-change:codebuild: [botocore] Update codebuild client to latest version
- update to version 1.6.14
  - bugfix:s3: [botocore] Fix regression in redirects in using wrong region
- update to version 1.6.13
  - bugfix:s3: [botocore] Fixed a bug where head object and bucket calls would attempt redirects incorrectly.
  - api-change:serverlessrepo: [botocore] Update serverlessrepo client to latest version
- update to version 1.6.12
  - api-change:ce: [botocore] Update ce client to latest version
  - enhancement:Credentials: [botocore] Add the ability to disable fetching credentials from EC2 metadata by setting the environment variable AWS_EC2_METADATA_DISABLED to 'true'.
  - api-change:config: [botocore] Update config client to latest version
  - api-change:elasticbeanstalk: [botocore] Update elasticbeanstalk client to latest version
  - api-change:glue: [botocore] Update glue client to latest version
  - api-change:medialive: [botocore] Update medialive client to latest version
  - bugfix:Credentials: [botocore] Fix a race condition related to assuming a role for the first time (#1405)
  - api-change:events: [botocore] Update events client to latest version
  - api-change:ecs: [botocore] Update ecs client to latest version
- update to version 1.6.11
  - api-change:elasticbeanstalk: [botocore] Update elasticbeanstalk client to latest version
- update to version 1.6.10
  - api-change:sagemaker: [botocore] Update sagemaker client to latest version
  - api-change:organizations: [botocore] Update organizations client to latest version
  - api-change:pinpoint: [botocore] Update pinpoint client to latest version
- update to version 1.6.9
  - api-change:lightsail: [botocore] Update lightsail client to latest version
- update to version 1.6.8
  - api-change:servicediscovery: [botocore] Update servicediscovery client to latest version
- update to version 1.6.7
  - api-change:cloudhsmv2: [botocore] Update cloudhsmv2 client to latest version
  - api-change:discovery: [botocore] Update discovery client to latest version
  - api-change:iot: [botocore] Update iot client to latest version
  - api-change:redshift: [botocore] Update redshift client to latest version
- update to version 1.6.6
  - api-change:pinpoint: [botocore] Update pinpoint client to latest version
  - api-change:ecs: [botocore] Update ecs client to latest version
  - api-change:rds: [botocore] Update rds client to latest version
  - api-change:mgh: [botocore] Update mgh client to latest version
- update to version 1.6.5
  - api-change:medialive: [botocore] Update medialive client to latest version
- update to version 1.6.4
  - api-change:ecs: [botocore] Update ecs client to latest version
- update to version 1.6.3
  - api-change:ssm: [botocore] Update ssm client to latest version
  - api-change:servicecatalog: [botocore] Update servicecatalog client to latest version
  - api-change:events: [botocore] Update events client to latest version
  - api-change:storagegateway: [botocore] Update storagegateway client to latest version
  - api-change:ec2: [botocore] Update ec2 client to latest version
* Thu Mar  1 2018 dmueller@suse.com
- update to version 1.6.2::
  - api-change:application-autoscaling: [botocore] Update application-autoscaling client to latest version
- update to version 1.6.1:
  - api-change:ecr: [botocore] Update ecr client to latest version
- update to version 1.6.0:
  - enhancement:Stubber: [botocore] Added the ability to add items to response metadata with the stubber.
  - api-change:sts: [botocore] Update sts client to latest version
  - api-change:route53: [botocore] Update route53 client to latest version
  - feature:s3: [botocore] Default to virtual hosted addressing regardless of signature version (boto/botocore`#1387 <https://github.com/boto/botocore/issues/1387>`__)
- update to version 1.5.36:
  - api-change:appstream: [botocore] Update appstream client to latest version
- update to version 1.5.35:
  - api-change:elbv2: [botocore] Update elbv2 client to latest version
  - api-change:ce: [botocore] Update ce client to latest version
- update to version 1.5.34:
  - api-change:ec2: [botocore] Update ec2 client to latest version
  - api-change:serverlessrepo: [botocore] Update serverlessrepo client to latest version
  - api-change:codecommit: [botocore] Update codecommit client to latest version
- update to version 1.5.33:
  - api-change:autoscaling: [botocore] Update autoscaling client to latest version
  - api-change:waf-regional: [botocore] Update waf-regional client to latest version
  - api-change:waf: [botocore] Update waf client to latest version
- update to version 1.5.32:
  - api-change:config: [botocore] Update config client to latest version
- update to version 1.5.31:
  - api-change:rds: [botocore] Update rds client to latest version
- update to version 1.5.30:
  - api-change:mediaconvert: [botocore] Update mediaconvert client to latest version
  - api-change:gamelift: [botocore] Update gamelift client to latest version
- update to version 1.5.29:
  - api-change:appsync: [botocore] Update appsync client to latest version
  - api-change:lex-models: [botocore] Update lex-models client to latest version
- update to version 1.5.28:
  - api-change:glacier: [botocore] Update glacier client to latest version
  - api-change:route53: [botocore] Update route53 client to latest version
- update to version 1.5.27:
  - api-change:guardduty: [botocore] Update guardduty client to latest version
  - api-change:cognito-idp: [botocore] Update cognito-idp client to latest version
  - api-change:rds: [botocore] Update rds client to latest version
  - api-change:ec2: [botocore] Update ec2 client to latest version
  - api-change:kms: [botocore] Update kms client to latest version
- update to version 1.5.26:
  - api-change:lex-runtime: [botocore] Update lex-runtime client to latest version
  - api-change:ec2: [botocore] Update ec2 client to latest version
  - api-change:lex-models: [botocore] Update lex-models client to latest version
- update to version 1.5.25:
  - api-change:ds: [botocore] Update ds client to latest version
  - api-change:appstream: [botocore] Update appstream client to latest version
  - api-change:medialive: [botocore] Update medialive client to latest version
  - api-change:budgets: [botocore] Update budgets client to latest version
  - api-change:gamelift: [botocore] Update gamelift client to latest version
  - api-change:dynamodb: [botocore] Update dynamodb client to latest version
  - api-change:dms: [botocore] Update dms client to latest version
  - api-change:mediastore: [botocore] Update mediastore client to latest version
- update to version 1.5.24:
  - api-change:servicediscovery: [botocore] Update servicediscovery client to latest version
  - api-change:servicecatalog: [botocore] Update servicecatalog client to latest version
  - api-change:ssm: [botocore] Update ssm client to latest version
  - api-change:glue: [botocore] Update glue client to latest version
- update to version 1.5.23:
  - api-change:cloud9: [botocore] Update cloud9 client to latest version
  - api-change:acm: [botocore] Update acm client to latest version
  - api-change:kinesis: [botocore] Update kinesis client to latest version
  - api-change:opsworks: [botocore] Update opsworks client to latest version
- update to version 1.5.22:
  - api-change:mturk: [botocore] Update mturk client to latest version
  - api-change:medialive: [botocore] Update medialive client to latest version
  - api-change:devicefarm: [botocore] Update devicefarm client to latest version
- update to version 1.5.21:
  - api-change:lambda: [botocore] Update lambda client to latest version
  - api-change:codebuild: [botocore] Update codebuild client to latest version
  - api-change:alexaforbusiness: [botocore] Update alexaforbusiness client to latest version
  - bugfix:Presign: [botocore] Fix issue where some events were not fired during the presigning of a request thus not including a variety of customizations (#1340)
  - enhancement:Credentials: [botocore] Improved error message when the source profile for an assume role is misconfigured. Fixes aws/aws-cli`#2763 <https://github.com/aws/aws-cli/issues/2763>`__
  - api-change:guardduty: [botocore] Update guardduty client to latest version
  - enhancment:Paginator: [botocore] Added paginators for a number of services where the result key is unambiguous.
- update to version 1.5.20:
  - api-change:budgets: [botocore] Update budgets client to latest version
- update to version 1.5.19:
  - api-change:glue: [botocore] Update glue client to latest version
  - api-change:transcribe: [botocore] Update transcribe client to latest version
- update to version 1.5.18:
  - api-change:sagemaker: [botocore] Update sagemaker client to latest version
- update to version 1.5.17:
  - api-change:ec2: [botocore] Update ec2 client to latest version
  - api-change:autoscaling-plans: [botocore] Update autoscaling-plans client to latest version
- update to version 1.5.16:
  - api-change:application-autoscaling: [botocore] Update application-autoscaling client to latest version
  - api-change:autoscaling-plans: [botocore] Update autoscaling-plans client to latest version
  - api-change:rds: [botocore] Update rds client to latest version
- update to version 1.5.15:
  - api-change:lambda: [botocore] Update lambda client to latest version
  - enhancement:cloudformation get_template template body ordering: [botocore] fixes boto/boto3`#1378 <https://github.com/boto/boto3/issues/1378>`__
- update to version 1.5.14:
  - api-change:glue: [botocore] Update glue client to latest version
- update to version 1.5.13:
  - api-change:ssm: [botocore] Update ssm client to latest version
  - api-change:elbv2: [botocore] Update elbv2 client to latest version
  - api-change:rds: [botocore] Update rds client to latest version
  - api-change:elb: [botocore] Update elb client to latest version
- update to version 1.5.12:
  - api-change:kms: [botocore] Update kms client to latest version
- update to version 1.5.11:
  - api-change:ds: [botocore] Update ds client to latest version
- update to version 1.5.10:
  - api-change:route53: [botocore] Update route53 client to latest version
  - api-change:discovery: [botocore] Update discovery client to latest version
  - api-change:codedeploy: [botocore] Update codedeploy client to latest version
- update to version 1.5.9:
  - api-change:ssm: [botocore] Update ssm client to latest version
  - api-change:inspector: [botocore] Update inspector client to latest version
  - api-change:snowball: [botocore] Update snowball client to latest version
- update to version 1.5.8:
  - api-change:rds: [botocore] Update rds client to latest version
- update to version 1.5.7:
  - api-change:workspaces: [botocore] Update workspaces client to latest version
- update to version 1.5.6:
  - api-change:ecs: [botocore] Update ecs client to latest version
  - api-change:ec2: [botocore] Update ec2 client to latest version
  - api-change:inspector: [botocore] Update inspector client to latest version
  - api-change:sagemaker: [botocore] Update sagemaker client to latest version
- update to version 1.5.5:
  - api-change:ec2: [botocore] Update ec2 client to latest version
  - enhancement:Paginator: [botocore] Added paginator support for lambda list aliases operation.
  - api-change:kinesisanalytics: [botocore] Update kinesisanalytics client to latest version
  - api-change:codebuild: [botocore] Update codebuild client to latest version
- update to version 1.5.4:
  - api-change:iot: [botocore] Update iot client to latest version
  - api-change:config: [botocore] Update config client to latest version
- update to version 1.5.3:
  - api-change:route53: [botocore] Update route53 client to latest version
  - api-change:apigateway: [botocore] Update apigateway client to latest version
  - api-change:mediastore-data: [botocore] Update mediastore-data client to latest version
* Sat Dec 16 2017 arun@gmx.de
- update to version 1.5.1:
  * api-change:appstream: [botocore] Update appstream client to latest
    version
- changes from version 1.5.0:
  * bugfix:Filters: Fixes a bug where parameters passed to resource
    collections could be mutated after the collections were created.
  * api-change:ses: [botocore] Update ses client to latest version
  * enhancement:credentials: [botocore] Moved the JSONFileCache from
    the CLI into botocore so that it can be used without importing
    from the cli.
  * feature:botocore dependency: Update dependency strategy to always
    take a floor on the most recent version of botocore. This means
    whenever there is a release of botocore, boto3 will release as
    well to account for the new version of botocore.
  * api-change:apigateway: [botocore] Update apigateway client to
    latest version
* Thu Dec  7 2017 arun@gmx.de
- specfile:
  * updated version for botocore
- update to version 1.4.8:
  * enhancement:botocore: Raised minor version dependency for botocore
* Fri Nov 24 2017 mpluskal@suse.com
- Require futures package only for python2 (boo#1069697)
* Thu Sep 14 2017 rjschwei@suse.com
- Update to version 1.4.7
  + botocore: Raised minor version dependency for botocore
- From 1.4.6
  + Logging: Switch log levels from INFO to DEBUG (#1208)
- From 1.4.5
  + s3: Add a LifecycleConfiguration resource to resolve issues with the
    existing Lifecycle resource.
* Thu May 11 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update source URL.
- Update to version 1.4.4
  * feature:``s3``: Add ability to disable thread use with ``use_threads`` option
  * bugfix:Resource: Fix resource hashing.
* Wed Jan 18 2017 astieger@suse.com
- fetch upstream sources to fix Factory submission
* Thu Dec 15 2016 rjschwei@suse.com
- Update to version 1.4.2 (bsc#1015776)
  + feature:ec2: Update client to latest version
* Wed Oct 26 2016 rjschwei@suse.com
- Fix the version requirement for botocore to ensure proper functioning of
  the API
* Wed Oct 26 2016 rjschwei@suse.com
- Add missing dependency on python-s3transfer
* Tue Oct 25 2016 rjschwei@suse.com
- Update to version 1.4.1 (bsc#1007084)
  + feature:Session: Expose available_profiles property for Session
    (``#704 <https://github.com/boto/boto3/issues/704>`__)
  + bugfix:s3: Fix issue when transfers would not exit quickly from signals
  + bugfix:sqs.Queue: Fix issue in DeadLetterSourceQueues collection
- From 1.4.0
  + feature:DynamoDB: Add request auto de-duplication based on specified
    primary keys for batch_writer. (#605)
  + feature:s3: Add managed file-like object uploads to S3 client, Bucket,
    and Object.
  + bugfix:Session: Fixed Session.__repr__ region argument name.
  + feature:s3: Add managed copies to S3 client, Bucket, and Object.
  + feature:s3: Add managed downloads to file-like objects in the S3 client,
    Bucket, and Object.
  + bugfix:s3: Port s3.transfer module to use s3transfer package. Please
    refer to Upgrading Notes when upgrading. In porting the logic over,
    various performance issues and bugs were fixed.
  + feature:s3: Add io_chunksize parameter to TransferConfig
* Mon Jun  6 2016 dmueller@suse.com
- fix source url
* Thu Jun  2 2016 jacobwinski@gmail.com
- Update to 1.3.1
  + feature:S3: Add custom load to ObjectSummary
  + feature:Session: Add method to get session credentials
  + bugfix:DynamoDB: Ensure batch writer never sends more than flush_amount (#483)
  + feature:Resources: Add get_available_subresources to Resources (#113)
* Fri Apr  8 2016 rjschwei@suse.com
- Fix version requirement for botocore
* Fri Apr  8 2016 rjschwei@suse.com
- Update to version 1.3.0 (bsc#974705)
  + feature:Session: Add get_available_partitions and get_available_regions
    methods to determine partitions and a service's available regions.
  + feature:EC2: Update resource model to include Route resources. (issue 532)
- From 1.2.6 - (2016-03-01)
  + bugfix:Resources: Properly alias identifiers which are also in the shape.
- From 1.2.5 - (2016-02-25)
  + bugfix:S3: Forward extra_args when using multipart downloads. (issue 503)
- From 1.2.4 - (2016-02-18)
  + feature:EC2: Add delete_tags() action to Instance resource. (issue 459)
  + feature:Session: Add region_name property on session. (issue 414)
  + bugfix:S3: Fix issue with hanging downloads. (issue 471)
* Tue Feb  2 2016 rjschwei@suse.com
- Include in SLE 12 (FATE#320335,bsc#962170)
* Tue Jan 19 2016 rjschwei@suse.com
- Fix license string
* Fri Jan 15 2016 rjschwei@suse.com
- Initial build
  + Version 1.2.3
